pub enum AnalysisKind {
Show 13 variants
Alias {
strategy: AliasStrategyKind,
},
Adg(AdgArgs),
Upg,
UpgStd,
Callgraph,
Dataflow {
debug: bool,
},
OwnedHeap,
Pathcond,
Range {
debug: bool,
},
Scan,
Ssa,
Mir,
DotMir,
}Variants
Alias
perform alias analysis (meet-over-paths by default)
Fields

strategy: AliasStrategyKindspecify the alias analysis strategy
Adg(AdgArgs)
generate API dependency graphs
Upg
generate unsafety propagation graphs for each module
UpgStd
generate unsafety propagation graphs for each module of the Rust standard library
Callgraph
generate callgraphs
Dataflow
generate dataflow graphs
OwnedHeap
analyze if the type holds a piece of memory on heap
Pathcond
extract path constraints
Range
perform range analysis
Scan
print basic information of the crate, e.g., the number of APIs
Ssa
print the SSA form of the crate
Mir
print the MIR of the crate
DotMir
print the MIR of the crate in dot format